@@ -15,10 +15,22 @@ NULL
 }
 
 external_pointer_address <- function(s) {
-  if (identical(Sys.getenv("TESTTHAT"), "true")) return("0x000000000")
+  if (identical(Sys.getenv("TESTTHAT"), "true")) return("0x123456789")
   .Call("external_pointer_address", PACKAGE = "constructive", s)
 }
 
 env_impl <- function(address) {
   .Call("objectFromAddress", PACKAGE = "constructive", address)
 }
+
+is_promise <- function(name, env = parent.frame()) {
+  .Call("is_promise", PACKAGE = "constructive", name, env)
+}
+
+promise_code <- function(name, env = parent.frame()) {
+  .Call("promise_code", PACKAGE = "constructive", name, env)
+}
+
+promise_env <- function(name, env = parent.frame()) {
+  .Call("promise_env", PACKAGE = "constructive", name, env)
+}
