@@ -13,7 +13,7 @@ construct_special_env <- function(x) {
 }
 
 env_memory_address <- function(x, by_name = FALSE) {
-  if (identical(Sys.getenv("TESTTHAT"), "true")) return("0x000000000")
+  if (identical(Sys.getenv("TESTTHAT"), "true")) return("0x123456789")
   if (by_name) rlang::env_label(x) else rlang::obj_address(x)
 }
 
@@ -64,7 +64,15 @@ fetch_parent_names <- function(x) {
 #' @export
 .env <- function(address, parents = NULL, ...) {
   force(parents) # to avoid notes
-  env_impl(address)
+  env <- env_impl(address)
+  if (is.null(env)) {
+    msg <- sprintf("No environment was found at the memory address '%s'", address)
+    info1 <- "It's likely that {constructive} was called in a different session to generate this code."
+    info2 <- "The environment might also have been garbage collected."
+    info3 <- "See `?opts_environment` for various alternatives to construct environment with persistent definitions."
+    abort(c(msg, i = info1, i = info2, i = info3))
+  }
+  env
 }
 
 update_predefinition <- function(envir, ...) {
