@@ -18,7 +18,7 @@ constructors$array <- new.env()
 opts_array <- function(constructor = c("array", "next"), ...) {
   .cstr_combine_errors(
     constructor <- .cstr_match_constructor(constructor, "array"),
-    ellipsis::check_dots_empty()
+    check_dots_empty()
   )
   .cstr_options("array", constructor = constructor)
 }
