@@ -1,5 +1,5 @@
 test_that("ordered", {
-  expect_snapshot({
+  expect_pipe_snapshot({
     # ordered
     construct(factor(month.abb, ordered = TRUE))
     construct(factor(month.abb, ordered = TRUE))
@@ -10,6 +10,7 @@ test_that("ordered", {
     construct(factor(month.abb, month.abb, ordered = TRUE))
     construct(factor(month.abb, month.abb, ordered = TRUE), opts_ordered("factor"))
     construct(factor(month.abb, month.abb, ordered = TRUE), opts_ordered("new_ordered"))
+    construct(factor(month.abb, levels = c(month.abb, NA), ordered = TRUE, exclude = NULL))
     construct(ordered(c(a="foo")))
   })
 })
